@@ -12,36 +12,43 @@ from urllib import urlretrieve
 import cPickle as pickle
 try:
     from PIL import Image
-except:
+except ImportError:
     import Image
 
-from PySide.QtCore import QSettings
+from PySide.QtCore import QSettings,QThread, Signal
 
-from threading import Thread
+#from threading import Thread
 
 import logging
 import os
 import socket
 
-class KhweeteurRefreshWorker(Thread):
+class KhweeteurRefreshWorker(QThread):
+
+    new_tweets = Signal(int, str)
+    error = Signal(str)
 
     def __init__(
         self,
         api,
         call,
-        dbus_handler,
+        #dbus_handler,
         me_user_id,
         ):
-        Thread.__init__(self, None)
+        QThread.__init__(self)
         self.api = api
 
         self.me_user_id = me_user_id
         self.call = call
-        self.dbus_handler = dbus_handler
+        #self.dbus_handler = dbus_handler
         socket.setdefaulttimeout(60)
 
-    def send_notification(self, msg, count):
-        self.dbus_handler.new_tweets(count, msg)
+#    def send_notification(self, msg, count):
+#        try:
+#            #self.dbus_handler.new_tweets(count, msg)
+#            self.new_tweets.emit(count, msg)
+#        except Exception, err:
+#            logging.debug('Retriever : %s' % str(err))
 
     def getCacheFolder(self):
         if not hasattr(self, 'folder_path'):
@@ -77,7 +84,6 @@ class KhweeteurRefreshWorker(Thread):
                         im.save(os.path.splitext(cache)[0] + '.png', 'PNG')
                     except StandardError, err:
                         logging.debug('DownloadProfilImage:' + str(err))
-                        print err
 
     def removeAlreadyInCache(self, statuses):
 
@@ -131,7 +137,6 @@ class KhweeteurRefreshWorker(Thread):
             return status.text
         except StandardError, err:
             logging.debug('getOneReplyContent:' + str(err))
-            print err
 
     def isMe(self, statuses):
         for status in statuses:
@@ -151,7 +156,6 @@ class KhweeteurRefreshWorker(Thread):
                         self.getOneReplyContent(status.in_reply_to_status_id)
             except StandardError, err:
                 logging.debug('getOneReplyContent:' + err)
-                print err
 
     def serialize(self, statuses):
         folder_path = self.getCacheFolder()
@@ -217,14 +221,28 @@ class KhweeteurRefreshWorker(Thread):
                 statuses = self.api.GetListStatuses(user=self.call.split(':'
                         )[1], id=self.call.split(':')[2], since_id=since)
                 logging.debug('%s finished' % self.call)
+
+            #Near GPS
+            elif self.call.startswith('Near:'):
+                logging.debug('%s running' % self.call)
+                logging.debug('geocode=(%s,%s,%s)' % (str(self.call.split(':')[1]),
+                         str(self.call.split(':')[2]), '1km'))
+                statuses = self.api.GetSearch(since_id=since,
+                        term='', geocode=(str(self.call.split(':')[1]),
+                         str(self.call.split(':')[2]), '1km'))
+                logging.debug('%s finished' % self.call)
             else:
                 logging.error('Unknow call : %s' % (self.call, ))
         except Exception, err:
 
             logging.debug('Retriever : %s' % str(err))
-            if settings.contains('ShowInfos'):
-                if settings.value('ShowInfos') == '2':
-                    self.dbus_handler.info('Khweeteur Error : ' + str(err))
+            try:
+                if settings.contains('ShowInfos'):
+                    if settings.value('ShowInfos') == '2':
+                        self.error.emit('Khweeteur Error : ' + str(err))
+                        #self.dbus_handler.info('Khweeteur Error : ' + str(err))
+            except Exception, err:
+                logging.debug('Retriever : %s' % str(err))
 
         self.removeAlreadyInCache(statuses)
         if len(statuses) > 0:
@@ -243,7 +261,7 @@ class KhweeteurRefreshWorker(Thread):
             statuses.reverse()
             settings.setValue(self.api._access_token_key + '_' + self.call,
                               statuses[0].id)
-            self.send_notification(self.call, len(statuses))
+            self.new_tweets.emit(len(statuses), self.call)
         settings.sync()
         logging.debug('%s refreshed' % self.call)
 
